Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(502)

Unified Diff: pkg/analysis_server/test/integration/test_all.dart

Issue 396383002: More integration tests for analysis server. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/test/integration/test_all.dart
diff --git a/pkg/analysis_services/test/search/test_all.dart b/pkg/analysis_server/test/integration/test_all.dart
similarity index 50%
copy from pkg/analysis_services/test/search/test_all.dart
copy to pkg/analysis_server/test/integration/test_all.dart
index 86364491209dae7ac9f4dd6073c862b217027724..177384d88572baa6d809724b964c6051811f1032 100644
--- a/pkg/analysis_services/test/search/test_all.dart
+++ b/pkg/analysis_server/test/integration/test_all.dart
@@ -2,21 +2,18 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library test.services.src.search.all;
-
import 'package:unittest/unittest.dart';
-import 'hierarchy_test.dart' as hierarchy_test;
-import 'search_engine_test.dart' as search_engine_test;
-
+import 'analysis_error_inttest.dart' as analysis_error_inttest;
+import 'server_domain_inttest.dart' as server_domain_inttest;
/**
* Utility for manually running all tests.
*/
main() {
groupSep = ' | ';
- group('search', () {
- hierarchy_test.main();
- search_engine_test.main();
+ group('analysis_server_integration', () {
+ analysis_error_inttest.main();
+ server_domain_inttest.main();
});
}
@@ -2,21 +2,18 @@
/**
- * Utility for manually running all tests.
+ * Utility for manually running all integration tests.
*/
main() {

Powered by Google App Engine
This is Rietveld 408576698